@@ -1,5 +1,5 @@
 /* GSequencer - Advanced GTK Sequencer
- * Copyright (C) 2005-2015 Joël Krähemann
+ * Copyright (C) 2005-2019 Joël Krähemann
  *
  * This file is part of GSequencer.
  *
@@ -408,6 +408,8 @@ ags_effect_pad_plugin_interface_init(AgsPluginInterface *plugin)
 void
 ags_effect_pad_init(AgsEffectPad *effect_pad)
 {  
+  AgsConfig *config;
+
   effect_pad->flags = 0;
 
   effect_pad->name = NULL;
@@ -415,6 +417,12 @@ ags_effect_pad_init(AgsEffectPad *effect_pad)
   effect_pad->version = AGS_EFFECT_PAD_DEFAULT_VERSION;
   effect_pad->build_id = AGS_EFFECT_PAD_DEFAULT_BUILD_ID;
 
+  config = ags_config_get_instance();
+  
+  effect_pad->samplerate = ags_soundcard_helper_config_get_samplerate(config);
+  effect_pad->buffer_size = ags_soundcard_helper_config_get_buffer_size(config);
+  effect_pad->format = ags_soundcard_helper_config_get_format(config);
+
   effect_pad->channel = NULL;
 
   effect_pad->cols = AGS_EFFECT_PAD_COLUMNS_COUNT;
@@ -803,6 +811,12 @@ ags_effect_pad_real_set_channel(AgsEffectPad *effect_pad, AgsChannel *channel)
   if(effect_pad->channel != NULL){
     effect_pad->flags &= (~AGS_EFFECT_PAD_PREMAPPED_RECALL);
   }
+
+  if(channel != NULL){
+    effect_pad->samplerate = channel->samplerate;
+    effect_pad->buffer_size = channel->buffer_size;
+    effect_pad->format = channel->format;
+  }
   
   effect_pad->channel = channel;
 
@@ -847,19 +861,23 @@ ags_effect_pad_real_resize_lines(AgsEffectPad *effect_pad, GType effect_line_typ
 {
   AgsEffectLine *effect_line;
 
-  AgsChannel *channel;
+  AgsChannel *channel, *next_channel, *nth_channel;
 
   GList *start_list, *list;
 
   guint i, j;  
   
   if(audio_channels > audio_channels_old){
-    channel = ags_channel_nth(effect_pad->channel,
-			      audio_channels_old);
+    nth_channel = ags_channel_nth(effect_pad->channel,
+				  audio_channels_old);
 
-    if(channel == NULL){
+    if(nth_channel == NULL){
       return;
     }
+
+    channel = nth_channel;
+
+    next_channel = NULL;
     
     for(i = audio_channels_old; i < audio_channels;){
       for(j = audio_channels_old % effect_pad->cols; j < effect_pad->cols && i < audio_channels; j++, i++){
@@ -873,15 +891,18 @@ ags_effect_pad_real_resize_lines(AgsEffectPad *effect_pad, GType effect_line_typ
 			 FALSE, FALSE,
 			 0, 0);
 
-	g_object_get(channel,
-		     "next", &channel,
-		     NULL);
+	/* iterate */
+	next_channel = ags_channel_next(channel);
 
-	if(channel != NULL){
-	  g_object_unref(channel);
-	}
+	g_object_unref(channel);
+
+	channel = next_channel;
       }
     }
+
+    if(next_channel != NULL){
+      g_object_unref(next_channel);
+    }
   }else{
 
     start_list = gtk_container_get_children((GtkContainer *) effect_pad->table);
