@@ -27,7 +27,12 @@
 
 #include <ags/plugin/ags_base_plugin.h>
 
+#if defined(AGS_W32API)
+#include <windows.h>
+#else
 #include <dlfcn.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -36,6 +41,9 @@
 
 #include <stdio.h>
 
+#include <string.h>
+#include <strings.h>
+
 #include <ags/config.h>
 
 void ags_lv2ui_manager_class_init(AgsLv2uiManagerClass *lv2ui_manager);
@@ -137,7 +145,7 @@ ags_lv2ui_manager_init(AgsLv2uiManager *lv2ui_manager)
       iter = lv2ui_env;
       i = 0;
       
-      while((next = index(iter, ':')) != NULL){
+      while((next = strchr(iter, ':')) != NULL){
 	ags_lv2ui_default_path = (gchar **) realloc(ags_lv2ui_default_path,
 						    (i + 2) * sizeof(gchar *));
 	ags_lv2ui_default_path[i] = g_strndup(iter,
@@ -157,6 +165,45 @@ ags_lv2ui_manager_init(AgsLv2uiManager *lv2ui_manager)
 
       ags_lv2ui_default_path[i] = NULL;
     }else{
+#if defined(AGS_W32API)
+      AgsApplicationContext *application_context;
+      
+      gchar *app_dir;
+      gchar *path;
+      
+      guint i;
+
+      i = 0;
+      
+      application_context = ags_application_context_get_instance();
+
+      app_dir = NULL;
+          
+      if(strlen(application_context->argv[0]) > strlen("\\gsequencer.exe")){
+	app_dir = g_strndup(application_context->argv[0],
+			    strlen(application_context->argv[0]) - strlen("\\gsequencer.exe"));
+      }
+
+      ags_lv2ui_default_path = (gchar **) malloc(2 * sizeof(gchar *));
+
+      path = g_strdup_printf("%s\\lv2ui",
+			     g_get_current_dir());
+      
+      if(g_file_test(path,
+		     G_FILE_TEST_IS_DIR)){
+	ags_lv2ui_default_path[i++] = path;
+      }else{
+	g_free(path);
+	
+	ags_lv2ui_default_path[i++] = g_strdup_printf("%s\\%s\\lv2ui",
+						      g_get_current_dir(),
+						      app_dir);
+      }
+      
+      ags_lv2ui_default_path[i++] = NULL;
+
+      g_free(app_dir);
+#else
       gchar *home_dir;
       guint i;
 
@@ -212,6 +259,7 @@ ags_lv2ui_manager_init(AgsLv2uiManager *lv2ui_manager)
       }
     
       ags_lv2ui_default_path[i++] = NULL;
+#endif
 #endif
     }
   }
@@ -588,10 +636,12 @@ ags_lv2ui_manager_load_blacklist(AgsLv2uiManager *lv2ui_manager,
     file = fopen(blacklist_filename,
 		 "r");
 
+#ifndef AGS_W32API    
     while(getline(&str, NULL, file) != -1){
       lv2ui_manager->lv2ui_plugin_blacklist = g_list_prepend(lv2ui_manager->lv2ui_plugin_blacklist,
 							     str);
     }
+#endif
   }
 
   pthread_mutex_unlock(lv2ui_manager_mutex);
