@@ -571,17 +571,19 @@ ags_thread_pool_pull(AgsThreadPool *thread_pool)
   pthread_mutex_unlock(&mutex);
   
   /* signal create threads */
-  pthread_mutex_lock(thread_pool->idle_mutex);
+  if(g_list_length(g_atomic_pointer_get(&(thread_pool->returnable_thread))) < g_atomic_int_get(&(thread_pool->max_unused_threads)) / 2){
+    pthread_mutex_lock(thread_pool->idle_mutex);
 
-  g_atomic_int_set(&(thread_pool->create_threads),
-		   TRUE);
+    g_atomic_int_set(&(thread_pool->create_threads),
+		     TRUE);
   
-  if(g_atomic_int_get(&(thread_pool->idle))){
-    pthread_cond_signal(thread_pool->idle_cond);
+    if(g_atomic_int_get(&(thread_pool->idle))){
+      pthread_cond_signal(thread_pool->idle_cond);
+    }
+  
+    pthread_mutex_unlock(thread_pool->idle_mutex);
   }
   
-  pthread_mutex_unlock(thread_pool->idle_mutex);
-
   return(AGS_THREAD(returnable_thread));
 }
 
